package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.vehicle.client.AssetClient;
import com.chelvc.cloud.vehicle.client.dto.MerchantAssetDTO;
import com.chelvc.cloud.vehicle.client.param.TransferNotifyParam;
import com.chelvc.cloud.vehicle.client.param.WithdrawNotifyParam;
import com.chelvc.cloud.vehicle.client.param.WithdrawParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 资产管理
 *
 * @author igl
 * @date 2024/05/26 16:08
 **/
@Slf4j
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class AssetController {

    private final AssetClient assetClient;
    /**
     * 获取商家端钱包信息
     *
     * @param merchantId 商家id
     */
    @GetMapping("/asset/merchant/{merchantId}")
    public MerchantAssetDTO getMerchantAsset(@PathVariable("merchantId") Long merchantId) {
        return this.assetClient.getMerchantAsset(merchantId);
    }

    /**
     * 提现接口
     *
     * @param param
     */
    @PutMapping("/asset/withdraw")
    public void withdraw(@RequestBody WithdrawParam param) {
        this.assetClient.withdraw(param);
    }

    /**
     * 提现回调接口
     *
     */
    @PostMapping("/asset/withdraw/notify")
    public void withdrawNotify(@RequestBody WithdrawNotifyParam param) {
        this.assetClient.withdrawNotify(param);
    }

    /**
     * 转账回调接口
     *
     */
    @PostMapping("/asset/transfer/notify")
    public void transferNotify(@RequestBody TransferNotifyParam param) {
        this.assetClient.transferNotify(param);
    }
}
